==> knowit-trinity-3.5.13.2.tar.xz: knowit-trinity-3.5.13.2/src/knowitlinks.h <==
/***************************************************************************
                          knowitlinks.h  -  description
                             -------------------
    begin                : nie gru 21 2003
    copyright            : (C) 2003 by Micha Rudolf
    email                : mrudolf@kdewebdev.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __KNOWIT_LINKS_H__
#define __KNOWIT_LINKS_H__
#include <klistbox.h>

class TQDropEvent;
class TQKeyEvent;
class TQDragEnterEvent;

class KnowitLinks : public KListBox
{
  Q_OBJECT
  TQ_OBJECT
public:
  KnowitLinks(TQWidget* parent=0, const char* name = 0);
protected:
  virtual void dragEnterEvent(TQDragEnterEvent* event);
  virtual void dropEvent(TQDropEvent* event);
  virtual void keyPressEvent(TQKeyEvent* e);
signals:
  void textDropped(const TQString& s, int flags);
  void linkRemove();
  void linkOpen();
  void linkOpenWith();
};

#endif

==> knowit-trinity_14.1.0.orig.tar.xz: knowit-trinity-14.1.0/src/knowitlinks.h <==
/***************************************************************************
                          knowitlinks.h  -  description
                             -------------------
    begin                : nie gru 21 2003
    copyright            : (C) 2003 by Micha Rudolf
    email                : mrudolf@kdewebdev.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __KNOWIT_LINKS_H__
#define __KNOWIT_LINKS_H__
#include <tdelistbox.h>

class TQDropEvent;
class TQKeyEvent;
class TQDragEnterEvent;

class KnowitLinks : public TDEListBox
{
  Q_OBJECT
  
public:
  KnowitLinks(TQWidget* parent=0, const char* name = 0);
protected:
  virtual void dragEnterEvent(TQDragEnterEvent* event);
  virtual void dropEvent(TQDropEvent* event);
  virtual void keyPressEvent(TQKeyEvent* e);
signals:
  void textDropped(const TQString& s, int flags);
  void linkRemove();
  void linkOpen();
  void linkOpenWith();
};

#endif
